==============================================
**capp** --- Cluster Analysis and Applications
==============================================

This module classes and functions for several applications based on
cluster expansions and decompositions.

.. toctree::
   :maxdepth: 3

   generate
